@@ -9,7 +9,7 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Bool Str CodeRef);
 use namespace::autoclean;
 
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 has is_strict => (
     is  => 'rw',
@@ -24,10 +24,10 @@ has is_escape_percent_sign => (
 has space => (
     is      => 'rw',
     isa     => Str,
-    default => q{ },
+    default => sub { q{ } },
 );
 
-sub reset_space { return shift->space(q{ }) }
+sub reset_space { return shift->space( q{ } ) }
 
 has formatter_code => (
     is      => 'rw',
@@ -234,13 +234,13 @@ __END__
 
 Locale::Utils::PlaceholderMaketext - Utils to expand maketext palaceholders
 
-$Id: PlaceholderMaketext.pm 479 2014-01-24 12:11:07Z steffenw $
+$Id: PlaceholderMaketext.pm 567 2015-02-02 07:32:47Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-Utils-PlaceholderMaketext/trunk/lib/Locale/Utils/PlaceholderMaketext.pm $
 
 =head1 VERSION
 
-1.000
+1.001
 
 =head1 SYNOPSIS
 
